/*

This is the implementation file for the MyEventSegment
class.  This class defines funtions that can be used to 
readout any module covered in the CAENcard class.  These
include the V785, V775, and V792


Tim Hoagland
11/3/04
s04.thoagland@wittenberg.edu

*/




#include "MyEventSegment.h"              

static char* pPacketVersion = "1.0";           
// Packet version -should be changed whenever major changes are made



//constructor set Packet details
MyEventSegment::MyEventSegment(short slot, unsigned short Id):    
  m_MyPacket(Id, string("My Packet"), string("Sample documented packet"),
	     string(pPacketVersion))
{
  module = new CAENcard(slot);   
        // Creates a new CAENcard object looking at the indicated VME slot

  ID = Id;                       
        // Sets the ID tag for the packet

}


// Is called right after the module is created.  All one time Setup
// should be done now.
void MyEventSegment::Initialize()
{
  module->reset();  //reset defaults
  system("sleep .1s"); //pause while reset happens
  module->clearData(); //clear data buffer

  //module->keepOverflowData();
  
  if(module->cardType()==775)
  {
    module->discardOverflowData();  
    module->discardUnderThresholdData();
    module->commonStop();  //common stop mode
    module->setRange(0x1E); // Set full range
  }
}


// Is called after reading data buffer
void MyEventSegment::Clear()
{
  module->clearData();          // Clear data buffer
}

unsigned int MyEventSegment::MaxSize()
{
  return 32*4+2;                
}


//Is called to readout data on module
DAQWordBufferPtr& MyEventSegment::Read(DAQWordBufferPtr& rBuf)
{
  for(int i=0;i<CAENTIMEOUT;i++)     
                  // Loop waits for data to become ready
    {
      if(module->dataPresent())      
                 // If data is ready stop looping
	{
	  break;
	}
    }
  if(module->dataPresent())           
                // Tests again that data is ready
    {
      rBuf = m_MyPacket.Begin(rBuf);  
               // Opens a new Packet

      module->readEvent(rBuf);        
               // Reads data into the Packet

      rBuf= m_MyPacket.End(rBuf);     
               // Closes the open Packet
    }
  return rBuf;
}
